//
//  PongTutorialViewController.m
//  PongTutorial
//
//  Created by Andrea Busi on 08/03/09.
//  Copyright "BubiDevs" 2009. All rights reserved.
//

#import "PongTutorialViewController.h"

//stato della partita
#define kPartitaInCorso 1
#define kPartitaFerma 2

//velocità della pallina sui due assi
#define kVelocitaPallaX 10
#define kVelocitaPallaY 20

//velocità di movimento del computer
#define kVelocitaMovComputer 15

//punteggio massimo, di fine partita
#define kPuntiVittoria 5

@implementation PongTutorialViewController

@synthesize barraUno, barraDue, pallina, textInizia, puntiUno, puntiDue, statoPartita, velocitaPalla;

// metodo eseguito al caricamento della vista
- (void)viewDidLoad {
	[super viewDidLoad];
	//impostiamo lo stato iniziale della partita su "fermo"
	self.statoPartita = kPartitaFerma;
	//settiamo la velocità della palla in un componente a due dimensioni
	velocitaPalla = CGPointMake(kVelocitaPallaX, kVelocitaPallaY);
	//avviamo un timer per il movimento della pallina
	[NSTimer scheduledTimerWithTimeInterval:0.05 target:self selector:@selector(gameLoop) userInfo:nil repeats:YES];
}

-(void)gameLoop{
	//controlliamo se la partita è in corso
	if (statoPartita == kPartitaInCorso){
		//muoviamo il centro della pallina, spostandolo con i valori della velocità
		pallina.center = CGPointMake(pallina.center.x + velocitaPalla.x, pallina.center.y + velocitaPalla.y);
		//se il centro è oltre le dimensioni orizzontali della vista, invertiamo la direzione (sempre sull'asse X)
		if (pallina.center.x > self.view.bounds.size.width || pallina.center.x < 0){
			velocitaPalla.x = -velocitaPalla.x;
		}
		//se il centro è oltre le dimensioni verticali della vista, invertiamo la direzione (sempre sull'asse Y)
		if (pallina.center.y > self.view.bounds.size.height || pallina.center.y < 0){
			velocitaPalla.y = -velocitaPalla.y;
		}
		//controlliamo se la pallina è a contatto con la barraDue (quella in basso)
		if (CGRectIntersectsRect(pallina.frame, barraDue.frame)){
			if (pallina.center.y < barraDue.center.y){
				velocitaPalla.y = -velocitaPalla.y;
			}
		}
		//controlliamo se la pallina è a contatto con la barraUno (quella in alto)
		if (CGRectIntersectsRect(pallina.frame, barraUno.frame)){
			if (pallina.center.y >= barraUno.center.y){
				velocitaPalla.y = -velocitaPalla.y;
			}
		}
		//AI computer
		if (pallina.center.y <= self.view.center.y){
			if (pallina.center.x < barraUno.center.x){
				CGPoint compLocation = CGPointMake(barraUno.center.x - kVelocitaMovComputer, barraUno.center.y);
				barraUno.center = compLocation;
			}
			if (pallina.center.x > barraUno.center.x){
				CGPoint compLocation = CGPointMake(barraUno.center.x + kVelocitaMovComputer, barraUno.center.y);
				barraUno.center = compLocation;
			}
		}
		//controlliamo se l'utente ha fatto punto
		if (pallina.center.y <= 0){
			punteggioDue++;
			[self reset:(punteggioDue >= kPuntiVittoria)]; 
		}
		//controlliamo se il computer ha fatto punto
		if (pallina.center.y > self.view.bounds.size.height){
			punteggioUno++;
			[self reset:(punteggioUno >= kPuntiVittoria)];
		}
	} else {
		//se la partita è ferma facciamo ricomparire la label per avviare il gioco
		if(textInizia.hidden){
			textInizia.hidden = NO;
		}
	}
}


-(void)reset:(BOOL) newGame{
	//mettiamo la partita sullo stato fermo
	self.statoPartita = kPartitaFerma;
	//posizioniamo la pallina al centro dello schermo
	pallina.center = self.view.center;
	//controlliamo se la aprtita è finita (un giocatore ha vinto)
	if (newGame){
		if (punteggioUno > punteggioDue){
			textInizia.text = @"Vince il computer!";
		}else {
			textInizia.text = @"Vince il giocatore!";
		}
		//azzeriamo i punteggi
		punteggioDue = 0;
		punteggioUno = 0;
	} else {//non ha vinto nessuno, si continua a giocare
		textInizia.text = @"Tocca per iniziare";
	}
	//settiamo le label con i due punteggi
	puntiDue.text = [NSString stringWithFormat:@"%d",punteggioDue];
	puntiUno.text = [NSString stringWithFormat:@"%d",punteggioUno];
}

-(void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event{
	//se la partita è ferma facciamola iniziare
	if(statoPartita == kPartitaFerma){
		textInizia.hidden = YES;
		statoPartita = kPartitaInCorso;
	} else if (statoPartita == kPartitaInCorso){//la partita è in corso, muoviamo le racchette
		[self touchesMoved:touches withEvent:event];
	}
}

-(void)touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event{
	//creiamo un oggetto con le informazioni del "touch" fatto dall'utente
	UITouch *touch = [[event allTouches] anyObject];
	//rileviamo le coordinate del tocco fatto dal'utente
	CGPoint location = [touch locationInView:touch.view];
	//creiamo un oggetto con le nuove coordinate in cui dobbiamo spostare la barra 
	//(quella dell'utente, ovvero la barraDue)
	CGPoint xLocation = CGPointMake(location.x,barraDue.center.y);
	//muoviamo la barra dell'utente
	barraDue.center = xLocation;
}


- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning]; // Releases the view if it doesn't have a superview
    // Release anything that's not essential, such as cached data
}


- (void)dealloc {
    [super dealloc];
	[pallina release];
	[barraUno release];
	[barraDue release];
	[puntiUno release];
	[puntiDue release];
	[textInizia release];
}

@end
